########Replication Code: When Civilians Are Attacked: Gender Equality and Terrorist Targeting##########
###Laura Huber##
###Journal of Conflict Resolution###

####If you have any questions about this replication code, please contact Laura Huber at lkhuber@emory.edu######



#Load Packages#
library(plyr)
library(dplyr)
library(MASS)
library(lme4)
library(lmtest)
library(sandwich)
library(ggplot2)
library(WDI)
library(mfx)
library(foreign)
library(stargazer)
library(readstata13)



##Load Data##
#Cross-national
terr.datsub <- read.csv( "C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/JCR Submission/Accepted/Huber JCR Replication Crossnational Data.csv",stringsAsFactors = F)

#India data
india.terr2a <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/FINAL India Terror Data.csv") 
##Most control variables in this dataset come from Iyer et al. 2012

#lag civilian_1_totallag
india.terr2a <- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                      lagdate = c(NA, head(civilian_1_total, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "civilian_1_totallag"

#Create lagged DV
india.terr2a$civilianproplag <- india.terr2a$civilian_1_sumlag / india.terr2a$civilian_1_totallag
india.terr2a$civilianproplag[is.na(india.terr2a$civilianproplag)] <- 0








######################Government Ideology Model Results#################################

#Load Koch and Cranmer  Data
dpi.dat <- read.csv("C:/Users/Laura Huber/Documents/Data/Government Ideology.csv",stringsAsFactors = F)
dpi.dat.sub <- subset(dpi.dat, select=c("countryname","year"  ,"execrlc","totalseats", "gov1seat" ,"gov1rlc",
                                        "gov2seat" ,"gov2rlc","gov3seat" ,"gov3rlc","govfrac"))

#Add countrycodes
library(countrycode)
dpi.dat.sub$ccode <- countrycode(dpi.dat.sub$countryname, "country.name","cown")

#recode NAs
dpi.dat.sub$execrlc[dpi.dat.sub$execrlc==0] <- NA
dpi.dat.sub$execrlc[dpi.dat.sub$execrlc==-999] <- NA
table(dpi.dat.sub$execrlc)

#merge data
terr.dat.rr <- merge(terr.datsub,dpi.dat.sub, by.x = c("cowcode","iyear"), by.y=c("ccode", "year"), all.x=T, all.y=F)
terr.dat.rr$exec.factor <- as.factor(terr.dat.rr$execrlc)
table(terr.dat.rr$exec.factor)
##unknown blank values

#recode without blank values
terr.dat.rr$exec.factor <- ifelse(terr.dat.rr$exec.factor=="Center","Center", ifelse(terr.dat.rr$exec.factor=="Left","Left",
                                                                                     ifelse(terr.dat.rr$exec.factor=="Right", "Right",NA)))
table(terr.dat.rr$exec.factor)

#factor executive ideology
terr.dat.rr$exec.factor <- as.factor(terr.dat.rr$exec.factor)


#Create lefitst government dichotomous variable
terr.dat.rr$govleft <- ifelse(terr.dat.rr$exec.factor=="Left",1,0)

#lag variables
terr.dat.rr <- ddply(.data = terr.dat.rr, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(govfrac, -1)))
names(terr.dat.rr)[names(terr.dat.rr) == "lagdate"] <- "govfraclag"


terr.dat.rr <- ddply(.data = terr.dat.rr, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(govleft, -1)))
names(terr.dat.rr)[names(terr.dat.rr) == "lagdate"] <- "govleftlag"


terr.dat.rr <- ddply(.data = terr.dat.rr, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(exec.factor, -1)))
names(terr.dat.rr)[names(terr.dat.rr) == "lagdate"] <- "exec.factorlag"
terr.dat.rr$exec.factorlag <- as.factor(terr.dat.rr$exec.factorlag)


#subset dataste to democracies
terr.datsub.dem <- subset(terr.dat.rr, terr.dat.rr$polity2.x>6)


#############################PROPORTIONAL MODELS####################################
##Executive Ideology Factored##
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x + exec.factorlag + govfraclag + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out2 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  MaternalMortalitylag1 +exec.factorlag+govfraclag + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out2 <- coeftest(out2, function(x) vcovHC(x, type = "HC1"))
out2

out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1 +exec.factorlag+govfraclag+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag +exec.factorlag +govfraclag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)

stargazer(out1, out2, out3, out4, digits = 2)



##Left Government Dichotomous Variable##
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x + govleftlag + govfraclag + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out2 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  MaternalMortalitylag1 +govleftlag+govfraclag + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out2 <- coeftest(out2, function(x) vcovHC(x, type = "HC1"))
out2

out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+govleftlag+govfraclag+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag+govleftlag +govfraclag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4


stargazer(out1, out2,out3,out4)








##Lagged Leftist Government Dichotomous Variable##

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x + govleftlag  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out2 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  MaternalMortalitylag1 +govleftlag + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out2 <- coeftest(out2, function(x) vcovHC(x, type = "HC1"))
out2

out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+govleftlag+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag+govleftlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub.dem)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3,out4)












####################################################ENDOGENEITY TESTS#########################################################
outendog1 <- lm(Fertility.x ~ domestic_civilian_attacksproportionlag1 + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag, data=terr.datsub)
outendog1 <- coeftest(outendog1, function(x) vcovHC(x, type = "HC1"))
outendog1

outendog2 <- lm(RatioSecondary ~ domestic_civilian_attacksproportionlag1 + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag, data=terr.datsub)
outendog2 <- coeftest(outendog2, function(x) vcovHC(x, type = "HC1"))
outendog2

outendog3 <- lm(LegislaturePctgreenlag ~ domestic_civilian_attacksproportionlag1 + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag, data=terr.datsub)
outendog3 <- coeftest(outendog3, function(x) vcovHC(x, type = "HC1"))
outendog3

outendog4 <- lm(LegQuota_Dichlag ~ domestic_civilian_attacksproportionlag1 + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag, data=terr.datsub)
outendog4 <- coeftest(outendog4, function(x) vcovHC(x, type = "HC1"))
outendog4


stargazer(outendog1,outendog2,outendog3,outendog4,digits=2)






#####################################################ROBUSTNESS CHECKS CROSS-NATIONAL###########################################
##############Marginal Effects############
##With Lagged DV##
#Fertility marginal effects
out1marg <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
                     + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
                     data=terr.datsub,atmean = TRUE,robust = T)


#Secondary Ratio marginal effects
out3marg <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
                     + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar + domestic_total_attackslag + TotalSecondarylag1
                     + domestic_civilian_attacksproportionlag1,data=terr.datsub,atmean = TRUE,robust = T)



#Legislative Representation marginal effects
out4marg <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
                     + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
                     + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,data=terr.datsub,atmean = TRUE,robust = T)




##Without Lagged DV##
#Fertility marginal effects
out1marg1 <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
                     + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag ,
                     data=terr.datsub,atmean = TRUE,robust = T)


#Secondary Ratio marginal effects
out3marg1 <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
                     + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar + domestic_total_attackslag + TotalSecondarylag1
                     ,data=terr.datsub,atmean = TRUE,robust = T)



#Legislative Representation marginal effects
out4marg1 <- logitmfx(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
                     + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
                     + domestic_total_attackslag,data=terr.datsub,atmean = TRUE,robust = T)









###############Alternate Measures of GE###############
#Maternal Mortality
outrb1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  MaternalMortalitylag1  + cllag + prlag + GDPlag1log+ cinc.ylag1
              + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
              family=binomial(logit), data=terr.datsub)
outrb1 <- coeftest(outrb1, function(x) vcovHC(x, type = "HC1"))
outrb1

#Schoole Enrollment Gender Parity
outrb2 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~ SchoolEnrollGenderParitylag1 + cllag + prlag + GDPlag1log+ cinc.ylag1
              + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+TotalSecondarylag1 + domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
              family=binomial(logit), data=terr.datsub)
outrb2 <- coeftest(outrb2, function(x) vcovHC(x, type = "HC1"))
outrb2
stargazer(outrb1, outrb2, digits=2)

#Sabrina Karim and Danny Hill Measures
#load and merge data
sabdannyrights <- read.csv("C:/Users/Laura Huber/Documents/Data/Karim Hill Rights.csv", stringsAsFactors = F)
terr.datsub <- merge(terr.datsub, sabdannyrights, by.x = c("cowcode", "iyear"), by.y=c("ccode", "year"), all.x = T,all.y = F)


sabdannyinclusion <- read.csv("C:/Users/Laura Huber/Documents/Data/Karim Hill Inclusion.csv", stringsAsFactors = F)
terr.datsub <- merge(terr.datsub, sabdannyinclusion, by.x = c("cowcode", "iyear"), by.y=c("ccode", "year"), all.x = T,all.y = F)

sabdannysecurity <- read.csv("C:/Users/Laura Huber/Documents/Data/Karim Hill Security.csv", stringsAsFactors = F)
terr.datsub <- merge(terr.datsub, sabdannysecurity, by.x = c("cowcode", "iyear"), by.y=c("ccode", "year"), all.x = T,all.y = F)

outrb1aa <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  rights.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag,
                family=binomial(logit), data=terr.datsub)
outrb1aa <- coeftest(outrb1aa, function(x) vcovHC(x, type = "HC1"))
outrb1aa

outrb1bb <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  inclusion.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag ,
                family=binomial(logit), data=terr.datsub)
outrb1bb <- coeftest(outrb1bb, function(x) vcovHC(x, type = "HC1"))
outrb1bb

outrb1cc <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  security.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
                + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag ,
                family=binomial(logit), data=terr.datsub)
outrb1cc <- coeftest(outrb1cc, function(x) vcovHC(x, type = "HC1"))
outrb1cc

stargazer(outrb1aa,outrb1bb,outrb1cc, digits=2)





outrb1a <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  rights.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
               + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
               family=binomial(logit), data=terr.datsub)
outrb1a <- coeftest(outrb1a, function(x) vcovHC(x, type = "HC1"))
outrb1a

outrb1b <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  inclusion.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
               + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
               family=binomial(logit), data=terr.datsub)
outrb1b <- coeftest(outrb1b, function(x) vcovHC(x, type = "HC1"))
outrb1b

outrb1c <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  security.mean  + cllag + prlag + GDPlag1log+ cinc.ylag1
               + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar+ domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
               family=binomial(logit), data=terr.datsub)
outrb1c <- coeftest(outrb1c, function(x) vcovHC(x, type = "HC1"))
outrb1c






#######################FULL COMBINED MODEL###############

outfull <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x + RatioSecondarylag1 + LegislaturePctgreenlag + LegQuota_Dichlag 
               + cllag + prlag + GDPlag1log+ cinc.ylag1 + Populationlag1log + war_anylag + ythbullag+muslim_maj + coldwar 
               + domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
               family=binomial(logit), data=terr.datsub)
outfull <- coeftest(outfull, function(x) vcovHC(x, type = "HC1"))
outfull




###############Country Fixed Effects##########
outfe1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
              + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
              + as.factor(cowcode) ,
              family=binomial(logit), data=terr.datsub)
outfe1 <- coeftest(outfe1, function(x) vcovHC(x, type = "HC1"))
outfe1


outfe3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
              + Populationlag1log + war_anylag + ythbullag + domestic_total_attackslag + TotalSecondarylag1
              +domestic_civilian_attacksproportionlag1+  as.factor(cowcode),
              family=binomial(logit), data=terr.datsub)
outfe3 <-coeftest(outfe3, function(x) vcovHC(x, type = "HC1"))
outfe3


outfe4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
              + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj+ coldwar 
              + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + as.factor(cowcode),
              family=binomial(logit), data=terr.datsub)
outfe4 <- coeftest(outfe4, function(x) vcovHC(x, type = "HC1"))
outfe4

stargazer(outfe1,outfe3,outfe4)





###############Year Fixed Effects##########
outfe1a <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
               + Populationlag1log + war_anylag + ythbullag +muslim_maj +  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
               + as.factor(iyear),
               family=binomial(logit), data=terr.datsub)
outfe1a <- coeftest(outfe1a, function(x) vcovHC(x, type = "HC1"))
outfe1a


outfe3a <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
               + Populationlag1log + war_anylag + ythbullag + domestic_total_attackslag + TotalSecondarylag1
               +domestic_civilian_attacksproportionlag1+ as.factor(iyear) + as.factor(cowcode),
               family=binomial(logit), data=terr.datsub)
outfe3a <-coeftest(outfe3a, function(x) vcovHC(x, type = "HC1"))
outfe3a


outfe4a <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
               + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj+ coldwar 
               + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,
               family=binomial(logit), data=terr.datsub)
outfe4a <- coeftest(outfe4a, function(x) vcovHC(x, type = "HC1"))
outfe4a






###############Country-Year Fixed Effects##########
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + as.factor(cowcode) + as.factor(iyear),
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + muslim_maj + domestic_total_attackslag + TotalSecondarylag1
            +domestic_civilian_attacksproportionlag1+ as.factor(iyear) + as.factor(cowcode),
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3


out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + as.factor(iyear) + as.factor(cowcode),
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4


stargazer(out1,out3,out4)







###############Interactions##########
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x*muslim_maj  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag +coldwar + ythbullag + domestic_total_attackslag +domestic_civilian_attacksproportionlag1,family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1*muslim_maj+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +coldwar + muslim_maj + domestic_total_attackslag + TotalSecondarylag1
            +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3


out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag*muslim_maj + LegQuota_Dichlag*muslim_maj + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log +coldwar + war_anylag + ythbullag + muslim_maj
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

out4a <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag*LegQuota_Dichlag+ cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log +coldwar + war_anylag + ythbullag + muslim_maj
             + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 ,
             family=binomial(logit), data=terr.datsub)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a


stargazer(out1,out3,out4, out4a)








#########ISRAEL PALESTINE CONTROL########

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1 + israelpal,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+ coldwar + domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + israelpal,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + israelpal,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)










######physical integrity rights control#######

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + physintlag,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj+ coldwar + domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + physintlag,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + physintlag,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)






########2 year lag independent variables#######

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag2.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag2+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj+ coldwar + domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag2 + LegQuota_Dichlag2 + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)








##########5 year lags########

terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(Fertilitylag2.x, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "Fertilitylag3.x"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(RatioSecondarylag2, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "RatioSecondarylag3"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegislaturePctgreenlag2, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegislaturePctgreenlag3"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegQuota_Dichlag2, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegQuota_Dichlag3"

terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(Fertilitylag3.x, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "Fertilitylag4.x"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(RatioSecondarylag3, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "RatioSecondarylag4"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegislaturePctgreenlag3, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegislaturePctgreenlag4"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegQuota_Dichlag3, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegQuota_Dichlag4"

terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(Fertilitylag4.x, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "Fertilitylag5.x"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(RatioSecondarylag4, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "RatioSecondarylag5"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegislaturePctgreenlag4, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegislaturePctgreenlag5"
terr.datsub <- ddply(.data = terr.datsub, .variables = .(cowcode), mutate,
                     lagdate = c(NA, head(LegQuota_Dichlag4, -1)))
names(terr.datsub)[names(terr.datsub) == "lagdate"] <- "LegQuota_Dichlag5"







out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag5.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag5+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag5 + LegQuota_Dichlag5 + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)








##############################ethnic data###############################
#load data
ethnic.dat <- read.dta("C:/Users/Laura Huber/Documents/Data/Ethnic Power Relations Dataset.dta")

terr.datsub <- merge(terr.datsub, ethnic.dat, by.x = c("cowcode","iyear"), by.y = c("cowcode","year"), all.x=T,all.y = F)
summary(terr.datsub$groups)


######Number of Ethnic Groups#######

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + groups,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + groups,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + groups,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=TRUE)





#######Ethnic Fractionalization######

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + elf,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + elf,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1+ elf ,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)







#######Polity 2######

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + polity2lag.x + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ polity2lag.x+ GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag+muslim_maj+ coldwar + domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + polity2lag.x + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 ,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4, no.space=T)










#######Decade Dummies#####

out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + decade80 + decade90,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + muslim_maj  + domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + decade80 + decade90,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + decade80 + decade90,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4)









##Oil Rents##
#load data
oil <-  WDI(country ="all", indicator = c("NY.GDP.PETR.RT.ZS"), 
            start = 1969, end = 2016, extra = F)

#Rename Variables
names(oil)[names(oil) == "NY.GDP.PETR.RT.ZS"] <- "Oil_Rents"

library(countrycode)
oil$cowcode <- countrycode(oil$country, "country.name", "cown")

#lag
oillag <- ddply(.data = oil, .variables = .(cowcode), mutate,
                lagdate = c(NA, head(Oil_Rents, -1)))
names(oillag)[names(oillag) == "lagdate"] <- "Oil_RentsLag"

#merge
terr.datsub <- merge(terr.datsub, oillag, by.x = c("cowcode", "iyear"), by.y=c("cowcode","year"), all.x=T,all.y=F)




out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1
            + Oil_RentsLag,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1


out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1 + Oil_RentsLag,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1 + Oil_RentsLag,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4

stargazer(out1,out3, out4)







#########################################################INDIA ROBUSTNESS CHECKS######################################################3

#lag variables for robustness checks
india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(womancm, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "womancmlag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(pfemale, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "pfemalelag"

india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(pwlit, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "pwlitlag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(plit, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "plitlag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(prural, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "prurallag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(murder_f, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "murder_flag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(elec_womres, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "elec_womreslag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(pcr_womtot, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "pcr_womtotlag"


india.terr2a<- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                     lagdate = c(NA, head(pmurder, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "pmurderlag"




###Percent of Population Female###

outindia2 <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag + pfemalelag ,
                 family=binomial(logit), data=india.terr2a)
outindia2 <- coeftest(outindia2, function(x) vcovHC(x, type = "HC1"))
outindia2



##Murder Rate##
outindia3 <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag + pmurderlag ,
                 family=binomial(logit), data=india.terr2a)
outindia3 <- coeftest(outindia3, function(x) vcovHC(x, type = "HC1"))
outindia3

stargazer(outindia2,outindia3,digits=2)




##Percent of Population Rural###

outindia4 <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag + prurallag ,
                 family=binomial(logit), data=india.terr2a)
outindia4 <- coeftest(outindia4, function(x) vcovHC(x, type = "HC1"))
outindia4


##Murder##
outindia5 <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag + murder_flag ,
                 family=binomial(logit), data=india.terr2a)
outindia5 <- coeftest(outindia5, function(x) vcovHC(x, type = "HC1"))
outindia5

##No fixed effects##
outindia6 <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag,
                 family=binomial(logit), data=india.terr2a)
outindia6 <- coeftest(outindia6, function(x) vcovHC(x, type = "HC1"))
outindia6

stargazer(outindia2,outindia3, outindia4, outindia5, outindia6,digits=2)




#########remove West Bengal#####
india.terr2a$civilian_1_sum1 <- india.terr2a$civilian_1_sum
india.terr2a$civilian_1_sum1 <- ifelse(india.terr2a$provstateid==28,NA,india.terr2a$civilian_1_sum)


outindia2 <- glm(cbind(civilian_1_sum1,noncivilian) ~ yearsincewres+ ipoplag  +indiagdp  + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + civilianproplag,
                 family=binomial(logit), data=india.terr2a)
outindia2 <- coeftest(outindia2, function(x) vcovHC(x, type = "HC1"))
outindia2


######Other model specifications####
mod1a <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian+ civilian_1_sumlag , data = india.terr2a)

mod1b <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + civilian_1_sumlag  + factor(provstateid) , data = india.terr2a)

mod1c <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + civilian_1_sumlag + factor(iyear), data = india.terr2a)

mod2a <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag , data = india.terr2a)
mod2a<- coeftest(mod2a, function(x) vcovHC(x, type = "HC1"))
mod2a

mod2b <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag + as.factor(provstateid) , data = india.terr2a)
mod2b<- coeftest(mod2b, function(x) vcovHC(x, type = "HC1"))
mod2b


stargazer(mod1a, mod1b, mod1c,digits=2)


mod2d <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag 
                + pfemalelag + as.factor(provstateid) , data = india.terr2a)
mod2d<- coeftest(mod2d, function(x) vcovHC(x, type = "HC1"))
mod2d

mod2e <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag 
                + pmurderlag+ as.factor(provstateid) , data = india.terr2a)
mod2e<- coeftest(mod2e, function(x) vcovHC(x, type = "HC1"))
mod2e

mod2f <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag 
                + prurallag+ as.factor(provstateid) , data = india.terr2a)
mod2f<- coeftest(mod2f, function(x) vcovHC(x, type = "HC1"))
mod2f

stargazer(mod2d,mod2e,mod2f)















###################ALTERNATE DV######################


#######################RC: Recode Food/Water######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 1
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#RC: Recode Food/Water, Telecomm, Transport, and Utilities as Civilian
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)












#######################RC: Recode Telecommunication######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 1
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)









#######################RC: Remove Abortion######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- NA
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag  + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a



out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)

















#######################RC: Recode Transportation######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 1
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0



terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)












#######################RC: Recode Utilities######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 1

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)









#######################RC: Private citizens######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 0
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0
terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)










#######################RC: Media######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 1
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 0
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0
terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)
colnames(dat.ind)

#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)













#######################RC: Business######################
dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
colnames(dat.end)
#Create binary DVs
#targtype1
dat.end$civilian_1 <- dat.end$targtype1
dat.end$civilian_1[dat.end$civilian_1==1] <- 0
dat.end$civilian_1[dat.end$civilian_1==5] <- 1
dat.end$civilian_1[dat.end$civilian_1==6] <- 1
dat.end$civilian_1[dat.end$civilian_1==8] <- 1
dat.end$civilian_1[dat.end$civilian_1==10] <- 1
dat.end$civilian_1[dat.end$civilian_1==11] <- 1
dat.end$civilian_1[dat.end$civilian_1==12] <- 1
dat.end$civilian_1[dat.end$civilian_1==14] <- 1
dat.end$civilian_1[dat.end$civilian_1==15] <- 1
dat.end$civilian_1[dat.end$civilian_1==18] <- 1

dat.end$civilian_1[dat.end$civilian_1==2] <- 0
dat.end$civilian_1[dat.end$civilian_1==3] <- 0
dat.end$civilian_1[dat.end$civilian_1==4] <- 0
dat.end$civilian_1[dat.end$civilian_1==7] <- 0
dat.end$civilian_1[dat.end$civilian_1==17] <- 0
dat.end$civilian_1[dat.end$civilian_1==22] <- 0
dat.end$civilian_1[dat.end$civilian_1==9] <- 0
dat.end$civilian_1[dat.end$civilian_1==16] <- 0
dat.end$civilian_1[dat.end$civilian_1==19] <- 0
dat.end$civilian_1[dat.end$civilian_1==21] <- 0

dat.end$civilian_1[dat.end$civilian_1==13] <- NA
dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
summary(terr.dat.recode$civilian_1_sum)
summary(terr.dat.recode$domestic_civilian_attacks)

terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
summary(terr.dat.recode$noncivilian)
summary(terr.dat.recode$noncivilian_attacks)

terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0
terr.dat.recode <- subset(terr.dat.recode, select=-c(stateabb.y,stateabb.x))

terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_total, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(civilian_1_sum, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
                         lagdate = c(NA, head(noncivilian, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


##without lagged dv
out1 <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

out3 <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1
            ,
            family=binomial(logit), data=terr.dat.recode)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

out4 <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + civilian_1_totallag,
            family=binomial(logit), data=terr.dat.recode)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)




#with lagged dv
out1a <- glm(cbind(civilian_1_sum,noncivilian) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out1a <- coeftest(out1a, function(x) vcovHC(x, type = "HC1"))
out1a

out3a <- glm(cbind(civilian_1_sum,noncivilian) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
             + Populationlag1log + war_anylag + ythbullag + civilian_1_totallag + TotalSecondarylag1 +propcivilianattacksrecodelag
             ,
             family=binomial(logit), data=terr.dat.recode)
out3a <-coeftest(out3a, function(x) vcovHC(x, type = "HC1"))
out3a

out4a <- glm(cbind(civilian_1_sum,noncivilian) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
             + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
             + civilian_1_totallag +propcivilianattacksrecodelag,
             family=binomial(logit), data=terr.dat.recode)
out4a <- coeftest(out4a, function(x) vcovHC(x, type = "HC1"))
out4a

stargazer(out1,out3,out4,out1a,out3a,out4a,digits = 2)





#India
dat.ind <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/gtdindia2.csv", stringsAsFactors = FALSE)


#Create binary DVs
#targtype1
dat.ind$civilian_1 <- dat.ind$targtype1
dat.ind$civilian_1[dat.ind$civilian_1==1] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==5] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==6] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==8] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==10] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==11] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==12] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==14] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==15] <- 1
dat.ind$civilian_1[dat.ind$civilian_1==18] <- 1

dat.ind$civilian_1[dat.ind$civilian_1==2] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==3] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==4] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==7] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==17] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==22] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==9] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==16] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==19] <- 0
dat.ind$civilian_1[dat.ind$civilian_1==21] <- 0

dat.ind$civilian_1[dat.ind$civilian_1==13] <- NA
dat.ind$civilian_1[dat.ind$civilian_1==20] <- NA


#Collapse data to country-year
#sum to create number of attacks against civilians per year 
dat.ind.sum <- aggregate(civilian_1~iyear+provstate, data=dat.ind, FUN="sum")
names(dat.ind.sum)[names(dat.ind.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
dat.ind.count <- aggregate(civilian_1~iyear+provstate
                           , data=dat.ind, FUN="length")
names(dat.ind.count)[names(dat.ind.count) == "civilian_1"] <- "civilian_1_total"

#merge
terr.ind.recode <- merge(dat.ind.sum, dat.ind.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
terr.ind.recode$noncivilian <- (terr.ind.recode$civilian_1_total - terr.ind.recode$civilian_1_sum)
colnames(terr.ind.recode) <- c("iyear","provstate","civilianattacks","totalattacks","noncivilianattacks")

terr.dat.recode <- merge(india.terr2a, terr.ind.recode,all.x = T, all.y = F)
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$civilianattacks)] <- 0

terr.dat.recode$noncivilianattacks[is.na(terr.dat.recode$noncivilianattacks)] <- 0
terr.dat.recode$civilianattacks[is.na(terr.dat.recode$totalattacks)] <- 0


terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(totalattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "totalattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(civilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilianattackslag"
terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(provstateid), mutate,
                         lagdate = c(NA, head(noncivilianattacks, -1)))
names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianattackslag"

terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilianattackslag + 0.01) / I(terr.dat.recode$noncivilianattackslag+ 0.01)
terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0

outindia <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                + totalattackslag ,
                family=binomial(logit), data=terr.dat.recode)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

outindia1 <- glm(cbind(civilianattacks,noncivilianattacks) ~ yearsincewres  +ipoplag + indiagdp   + insurgencylag + no_election_sincewres
                 + civilian_1_totallag + propcivilianattacksrecodelag,
                 family=binomial(logit), data=terr.dat.recode)
outindia1 <- coeftest(outindia1, function(x) vcovHC(x, type = "HC1"))
outindia1

stargazer(outindia,outindia1)



################################################END JCR APPENDIX######################################


#End.