########Replication Code: When Civilians Are Attacked: Gender Equality and Terrorist Targeting##########
###Laura Huber##
###Journal of Conflict Resolution###

####If you have any questions about this replication code, please contact Laura Huber at lkhuber@emory.edu######



#Load Packages#
library(plyr)
library(dplyr)
library(MASS)
library(lme4)
library(lmtest)
library(sandwich)
library(ggplot2)
library(WDI)
library(mfx)
library(stargazer)




##########################################################CROSS-NATIONAL MODELS##########################################################
#Download Data#
terr.datsub <- read.csv( "C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/JCR Submission/Accepted/Huber JCR Replication Crossnational Data.csv",stringsAsFactors = F)
######If you would like to see the code for how the GTD data was aggregated and merged, please contact the author. This is the final dataset used in the analysis, but I am happy to share the code for how it was constructed.


#####Example of how Dataset was Created from GTD data#####
#####DO NOT RUN FOR THIS ANALYSIS AS THE TERR.DATSUB DATA HAS ALREADY BEEN AGGREAGTED#####
#dat.end <- read.csv("C:/Users/Laura Huber/Documents/Data/GTD Domestic Enders.csv", stringsAsFactors = FALSE)
#colnames(dat.end)
#Create binary DVs
#targtype1
#dat.end$civilian_1 <- dat.end$targtype1
#dat.end$civilian_1[dat.end$civilian_1==1] <- 1
#dat.end$civilian_1[dat.end$civilian_1==5] <- 1
#dat.end$civilian_1[dat.end$civilian_1==6] <- 1
#dat.end$civilian_1[dat.end$civilian_1==8] <- 1
#dat.end$civilian_1[dat.end$civilian_1==10] <- 1
#dat.end$civilian_1[dat.end$civilian_1==11] <- 1
#dat.end$civilian_1[dat.end$civilian_1==12] <- 1
#dat.end$civilian_1[dat.end$civilian_1==14] <- 1
#dat.end$civilian_1[dat.end$civilian_1==15] <- 1
#dat.end$civilian_1[dat.end$civilian_1==18] <- 1

#dat.end$civilian_1[dat.end$civilian_1==2] <- 0
#dat.end$civilian_1[dat.end$civilian_1==3] <- 0
#dat.end$civilian_1[dat.end$civilian_1==4] <- 0
#dat.end$civilian_1[dat.end$civilian_1==7] <- 0
#dat.end$civilian_1[dat.end$civilian_1==17] <- 0
#dat.end$civilian_1[dat.end$civilian_1==22] <- 0
#dat.end$civilian_1[dat.end$civilian_1==9] <- 0
#dat.end$civilian_1[dat.end$civilian_1==16] <- 0
#dat.end$civilian_1[dat.end$civilian_1==19] <- 0
#dat.end$civilian_1[dat.end$civilian_1==21] <- 0

#dat.end$civilian_1[dat.end$civilian_1==13] <- NA
#dat.end$civilian_1[dat.end$civilian_1==20] <- NA

#Collapse data to country-year
#sum to create number of attacks against civilians per year 
#dat.end.sum <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="sum")
#names(dat.end.sum)[names(dat.end.sum) == "civilian_1"] <- "civilian_1_sum"

#length to create number of total attacks per year 
#dat.end.count <- aggregate(civilian_1~iyear+country, data=dat.end, FUN="length")
#names(dat.end.count)[names(dat.end.count) == "civilian_1"] <- "civilian_1_total"

#merge
#terr.mena <- merge(dat.end.sum, dat.end.count, all.x=T, suffixes = c("", ".drop"))

##create noncivilian attack sum
#terr.mena$noncivilian <- (terr.mena$civilian_1_total - terr.mena$civilian_1_sum)

#terr.dat.recode <- merge(terr.datsub, terr.mena, by.x=c("country.x.x", "iyear"), by.y=c("country", "iyear"),all.x = T, all.y = F)
#terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_sum)] <- 0
#summary(terr.dat.recode$civilian_1_sum)
#summary(terr.dat.recode$domestic_civilian_attacks)

#terr.dat.recode$noncivilian[is.na(terr.dat.recode$noncivilian)] <- 0
#summary(terr.dat.recode$noncivilian)
#summary(terr.dat.recode$noncivilian_attacks)

#terr.dat.recode$civilian_1_sum[is.na(terr.dat.recode$civilian_1_total)] <- 0

#terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
#                         lagdate = c(NA, head(civilian_1_total, -1)))
#names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_totallag"
#terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
#                         lagdate = c(NA, head(civilian_1_sum, -1)))
#names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "civilian_1_sumlag"
#terr.dat.recode <- ddply(.data = terr.dat.recode, .variables = .(cowcode), mutate,
#                         lagdate = c(NA, head(noncivilian, -1)))
#names(terr.dat.recode)[names(terr.dat.recode) == "lagdate"] <- "noncivilianlag"

#terr.dat.recode$propcivilianattacksrecodelag <- I(terr.dat.recode$civilian_1_sumlag + 0.01) / I(terr.dat.recode$civilian_1_totallag+ 0.01)
#terr.dat.recode$propcivilianattacksrecodelag[is.na(terr.dat.recode$propcivilianattacksrecodelag)] <- 0


############################Table 1: Logistic Regression Results: Gender Equality and the Proportion of Civilian-Oriented Attacks (No Lagged Dependent Variable)####################################

#Fertility Model 1
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1, function(x) vcovHC(x, type = "HC1"))
out1

#Secondary Ratio Model 2
out3 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag + TotalSecondarylag1,
            family=binomial(logit), data=terr.datsub)
out3 <-coeftest(out3, function(x) vcovHC(x, type = "HC1"))
out3

#Legislature Percent Model 3
out4 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj+ coldwar 
            + domestic_total_attackslag,
            family=binomial(logit), data=terr.datsub)
out4 <- coeftest(out4, function(x) vcovHC(x, type = "HC1"))
out4
summary(out4)

#print Table 1
stargazer(out1,out3,out4,digits = 2)







#############################Table 2: Logistic Regression Results: Gender Equality and the Proportion of Civilian-Oriented Attacks (Lagged Dependent Variable)####################################

#Model 4 Fertility
out1.laggeddv <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag +domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out1 <- coeftest(out1.laggeddv, function(x) vcovHC(x, type = "HC1"))
out1.laggeddv


#Model 5 Secondary Ratio
out3.laggeddv <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  RatioSecondarylag1+ cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj + coldwar+ domestic_total_attackslag + TotalSecondarylag1
            + domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out3.laggeddv <-coeftest(out3.laggeddv, function(x) vcovHC(x, type = "HC1"))
out3.laggeddv


#Model 6 Legislative Representation
out4.laggeddv <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1
            + cllag + prlag + GDPlag1log + Populationlag1log  + war_anylag + ythbullag + muslim_maj + coldwar 
            + domestic_total_attackslag+domestic_civilian_attacksproportionlag1,
            family=binomial(logit), data=terr.datsub)
out4.laggeddv <- coeftest(out4.laggeddv, function(x) vcovHC(x, type = "HC1"))
out4.laggeddv

#print
stargazer(out1.laggeddv,out3.laggeddv,out4.laggeddv,digits = 2)







#############################Figure 1: Predicted Probabilities Plot: Fertility Rates and Proportion of Civilian Attacks#############################
#model
out1 <- glm(cbind(domestic_civilian_attacks,domestic_noncivilian_attacks) ~  Fertilitylag1.x  + cllag + prlag + GDPlag1log+ cinc.ylag1
            + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+  domestic_total_attackslag,
            family=binomial(logit), data=terr.datsub)

#make dataset
newdata <- data.frame(Fertilitylag1.x = 1.076:8.713, 
                      cinc.ylag1 = .007,
                      cllag = 4.075,
                      prlag = 4.093,
                      GDPlag1log = 23.183,
                      Populationlag1log = 15.889,
                      war_anylag = 0,
                      ythbullag = 1.046,
                      muslim_maj = 0,
                      coldwar = 1,
                      domestic_total_attackslag = 7.681)

#Create Predicted Probabilities
preds <- predict(out1, newdata, type="response",se.fit=TRUE)

#Create Predicted Probalities Plotting Dataset
predf <- preds$fit # predicted
lower <- preds$fit - (1.96*preds$se.fit) # lower bounds
upper <- preds$fit + (1.96*preds$se.fit) # upper bounds
fert <- 1:8
phats <- cbind(fert,predf, lower,upper)
phats <- as.data.frame(phats)
phats


#Figure 1: 
ggplot(phats, aes(x=fert, y=predf)) + theme_bw() + geom_ribbon(aes(ymin=lower, ymax= upper), alpha=0.1)+
  stat_smooth(method="glm", se = F, size=.9)+ 
  xlab("Fertility (Births per Woman)") + ylab("Predicted Ratio of Civilian Attacks") +
  ggtitle("Predicted Probabilities: Fertility and Proportion Civilian Attacks") + 
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=14))


#Alternate Figure: 100 percent scale
ggplot(phats, aes(x=fert, y=predf)) + theme_bw() + geom_ribbon(aes(ymin=lower, ymax= upper), alpha=0.1)+
  stat_smooth(method="glm", se = F, size=.9)+ scale_y_continuous(limits = c(0,1))+
  xlab("Fertility") + ylab("Predicted Ratio of Civilian Attacks") +
  ggtitle("Predicted Probabilities: Fertility and Proportion Civilian Attacks") 







##################################Table 3: Negative Binomial Results: Gender Equality and the Number of Terrorist Attacks##########################################
#Model 7 Civilian Attacks
negbinom1a <- glm.nb(domestic_civilian_attacks ~ Fertilitylag1.x + cinc.ylag1 + cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar  + domestic_civilian_attackslag+ factor(cowcode), 
                    data = terr.datsub)
summary(negbinom1a)

#Model 8 Government Attacks
negbinom1b <- glm.nb(domestic_noncivilian_attacks ~ Fertilitylag1.x + cinc.ylag1 + cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar + domestic_noncivilian_attackslag+ factor(cowcode), 
                    data = terr.datsub)
summary(negbinom1b)

#Model 9 Total Attacks
negbinom1c <- glm.nb(domestic_total_attacks ~ Fertilitylag1.x + cinc.ylag1 + cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar + domestic_total_attackslag + factor(cowcode), 
                    data = terr.datsub)
summary(negbinom1c)

#print
stargazer(negbinom1a,negbinom1b,negbinom1c, digits=2)



##################################Figure 2: Probability of Domestic Civilian Attacks Given the Fertility Rate##################################
#Create dataset
newdata1 <- data.frame(Fertilitylag1.x = 1.872:8.714,
                       domestic_civilian_attackslag = mean(terr.datsub$domestic_civilian_attackslag,na.rm=TRUE),
                       cinc.ylag1 = mean(terr.datsub$cinc.ylag1, na.rm=TRUE),
                       cllag = mean(terr.datsub$cllag, na.rm=TRUE),
                       prlag = mean(terr.datsub$prlag,na.rm=TRUE),
                       GDPlag1log = mean(terr.datsub$GDPlag1log,na.rm=TRUE),
                       Populationlag1log = mean(terr.datsub$Populationlag1log,na.rm=TRUE),
                       coldwar = mean(terr.datsub$coldwar,na.rm=TRUE),
                       war_anylag = mean(terr.datsub$war_anylag,na.rm=TRUE),
                       ythbullag = mean(terr.datsub$ythbullag,na.rm=TRUE),
                       muslim_maj = 0,
                       cowcode = 70)

#Predict values 
newdata2 <- predict(negbinom1a, newdata1, type = "link", se.fit=TRUE)
newdata2 <- within(newdata2, {
  DaysAbsent <- exp(fit)
  LL <- exp(fit - 1.96 * se.fit)
  UL <- exp(fit + 1.96 * se.fit)
})

Fertilitylag1 <- c(1.872,2.872,3.872,4.872,5.872,6.872,7.872,8.872)
NumberAttacks <- c(0.7928353, 0.8952185, 1.0108229, 1.1413559, 1.2887454, 1.4551681, 1.6430818, 1.8552619)
LL <- c(0.6071956, 0.7333885, 0.8714299, 0.9982575, 1.0916798, 1.1615209, 1.2218700, 1.2790356)
UL <- c(1.035231 ,1.092758, 1.172513, 1.304967, 1.521385, 1.823053, 2.209497, 2.691088 )
newdata2 <- cbind(Fertilitylag1, NumberAttacks,LL,UL)
newdata2 <- as.data.frame(newdata2)


#Plot data
ggplot(newdata2, aes(Fertilitylag1, NumberAttacks)) +
  geom_ribbon(aes(ymin = LL, ymax = UL), alpha = .1) +
  geom_line(aes(Fertilitylag1, NumberAttacks), size = 1, colour="blue") +
  labs(x = "Fertility (Births per Woman)", y = "Predicted Number of Domestic Civilian Attacks") + 
  theme_bw()+ ggtitle("Predicted Probability: Fertility and the Number of Civilian Attacks")+
  theme(text = element_text(size=13))








#####################Other Cross-National Negative Binomial Models, Not in Paper##############
######Secondary Ratio######

##Civilian Attacks##
negbinom4 <- glm.nb(domestic_civilian_attacks ~ RatioSecondarylag1  + cinc.ylag1 +  cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_civilian_attackslag
                    + factor(cowcode) , data = terr.datsub)
summary(negbinom4)

##Government Attacks###
negbinom4a <- glm.nb(domestic_noncivilian_attacks ~ RatioSecondarylag1  + cinc.ylag1 +  cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_noncivilian_attackslag
                    + factor(cowcode) , data = terr.datsub)
summary(negbinom4a)

##Total Attacks##
negbinom4b <- glm.nb(domestic_total_attacks ~ RatioSecondarylag1  + cinc.ylag1 +  cllag + prlag + GDPlag1log
                     + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar+ domestic_total_attackslag
                     + factor(cowcode) , data = terr.datsub)
summary(negbinom4b)
stargazer(negbinom4, negbinom4a,negbinom4b, digits=2)





#######Legislature Percent######
##Civilian Attacks##
negbinom2 <- glm.nb(domestic_civilian_attacks ~ LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1+ cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar + domestic_total_attackslag + domestic_civilian_attackslag
                    + factor(cowcode) , data = terr.datsub)
summary(negbinom2)

##Government Attacks##
negbinom2a <- glm.nb(domestic_noncivilian_attacks ~ LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1+ cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar + domestic_total_attackslag + domestic_noncivilian_attackslag
                    + factor(cowcode) , data = terr.datsub)
summary(negbinom2a)

##Total Attacks##
negbinom2b <- glm.nb(domestic_total_attacks ~ LegislaturePctgreenlag + LegQuota_Dichlag + cinc.ylag1+ cllag + prlag + GDPlag1log
                    + Populationlag1log + war_anylag + ythbullag +muslim_maj+ coldwar + domestic_total_attackslag + domestic_total_attackslag
                    + factor(cowcode) , data = terr.datsub)
summary(negbinom2b)

stargazer(negbinom2, negbinom2a, negbinom2b, digits=2)





##########################################################INDIA SUBNATIONAL MODELS##########################################################

#load india data
india.terr2a <- read.csv("C:/Users/Laura Huber/Documents/Papers/Gender Equality and Terrorism/FINAL India Terror Data.csv")

#lag civilian_1_totallag
india.terr2a <- ddply(.data = india.terr2a, .variables = .(provstateid), mutate,
                      lagdate = c(NA, head(civilian_1_total, -1)))
names(india.terr2a)[names(india.terr2a) == "lagdate"] <- "civilian_1_totallag"



##############Figure 3: Number of Civilian- and Government-Oriented Attacks in India as Years Since Women's Reservation Increased###########
civdat1 <- subset(india.terr2a, select=c(civilian_1_sum, yearsincewres))
civdat1$type <- "Civilian"
civdat2 <- subset(india.terr2a, select=c(noncivilian, yearsincewres))
civdat2$type <- "Government"
colnames(civdat1) <- c("count","years","Type")
colnames(civdat2) <- c("count","years","Type")
civdat <- rbind(civdat1, civdat2)

ggplot(aes(x=years, y=count, group=Type,fill=Type), data = civdat) +
  geom_bar(stat = 'identity', position = 'dodge') + xlab("Years Since Women's Reservation") + ylab("Number of Attacks") +
  theme_bw() + theme(
    plot.title = element_text( size=14),
    axis.title.x = element_text( size=14),
    axis.title.y = element_text( size=14)
  ) + scale_fill_manual(values=c("dark gray", "black"))



#Create lagged DV
india.terr2a$civilianproplag <- india.terr2a$civilian_1_sumlag / india.terr2a$civilian_1_totallag
india.terr2a$civilianproplag[is.na(india.terr2a$civilianproplag)] <- 0


##############Table 4: Sub-National Results: Years Since Gender Quota and Proportion Civilian Terrorist Attacks##############
##Model 10
outindia <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres + ipoplag + indiagdp  + insurgencylag + no_election_sincewres
                + civilian_1_totallag ,
                family=binomial(logit), data=india.terr2a)
outindia <- coeftest(outindia, function(x) vcovHC(x, type = "HC1"))
outindia

##Model 11
outindia.laggeddv <- glm(cbind(civilian_1_sum,noncivilian) ~ yearsincewres + ipoplag + indiagdp  + insurgencylag + no_election_sincewres
                + civilian_1_totallag + civilianproplag,
                family=binomial(logit), data=india.terr2a)
outindia.laggeddv <- coeftest(outindia.laggeddv, function(x) vcovHC(x, type = "HC1"))
outindia.laggeddv


##Model 12
mod2a <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + as.factor(provstateid) , data = india.terr2a)
mod2a<- coeftest(mod2a, function(x) vcovHC(x, type = "HC1"))
mod2a


##Model 13
mod2b <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres + civilian_1_sumlag + as.factor(provstateid) , data = india.terr2a)
mod2b<- coeftest(mod2b, function(x) vcovHC(x, type = "HC1"))
mod2b

#print
stargazer(outindia, outindia.laggeddv, mod2a, mod2b, digits=2)






#########################Figure 4: Predicted Probabilities Following Women's Reservation#########################
#Plot Model
mod2b <- glm.nb(civilian_1_sum ~ yearsincewres + noncivilian + ipoplag + indiagdp + insurgencylag   + no_election_sincewres
                + civilian_1_sumlag, data = india.terr2a)

#Create Plot Dataset
newdata <- data.frame(yearsincewres=0:21,
                      noncivilian=mean(india.terr2a$noncivilian,na.rm=TRUE),
                      ipoplag=mean(india.terr2a$ipoplag,na.rm=TRUE),
                      indiagdp=79,203,221,
                      insurgencylag=0,
                      no_election_sincewres=1, 
                      civilian_1_sumlag=mean(india.terr2a$civilian_1_sumlag,na.rm=TRUE))

#Generate predicted probabilities
preds <- predict(mod2b, newdata, type="response",se.fit=TRUE)

#Create predicted probabilties datset
YearsSince <- c(1:21)
NumberAttacks <- c(0.7928353, 0.8952185, 1.0108229, 1.1413559, 1.2887454, 1.4551681, 1.6430818, 1.8552619)
LL <- c(0.6071956, 0.7333885, 0.8714299, 0.9982575, 1.0916798, 1.1615209, 1.2218700, 1.2790356)
UL <- c(1.035231 ,1.092758, 1.172513, 1.304967, 1.521385, 1.823053, 2.209497, 2.691088 )
newdata2 <- cbind(Fertilitylag1, NumberAttacks,LL,UL)
newdata2 <- as.data.frame(newdata2)


#Create Plot
ggplot(newdata2, aes(Fertilitylag1, NumberAttacks)) +
  geom_ribbon(aes(ymin = LL, ymax = UL), alpha = .1) +
  geom_line(aes(Fertilitylag1, NumberAttacks), size = 1, colour="blue") +
  labs(x = "Fertility Rate", y = "Predicted Number of Domestic Civilian Attacks") + theme_bw()



###End Main Paper Results####

#######Online Supplementary Materials and Robustness Checks Replication Code can be found in a seperate file.######

#End. 